%global alsacfgdir %{_prefix}/lib/alsa
Summary:       Advanced Linux Sound Architecture (ALSA) utilities
Name:          alsa-utils
Version:       1.2.9
Release:       5%{?dist}
License:       GPLv2+
URL:           http://www.alsa-project.org/
Source0:       ftp://ftp.alsa-project.org/pub/utils/alsa-utils-%{version}.tar.bz2
Source1:       alsaunmute
Source2:       alsaunmute.1
Source3:       alsa.rules
Source4:       alsactl.conf
Source5:       alsa-restore.service
Source6:       alsa-state.service

BuildRequires: gcc alsa-lib-devel >= %{version}
BuildRequires: libsamplerate-devel ncurses-devel gettext-devel
BuildRequires: xmlto python3-docutils systemd systemd-devel
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
Requires:      alsa-lib >= %{version}
Requires:      alsa-ucm >= %{version}

%description
This package contains command line utilities for the Advanced Linux Sound
Architecture (ALSA).

%package -n alsa-ucm-utils
Summary: Advanced Linux Sound Architecture (ALSA) - Use Case Manager

%description -n alsa-ucm-utils
This package contains Use Case Manager tools for Advanced Linux Sound
Architecture (ALSA) framework.

%package -n alsa-topology-utils
Summary: Advanced Linux Sound Architecture (ALSA) - Topology
Requires: alsa-topology >= %{version}

%description -n alsa-topology-utils
This package contains topology tools for Advanced Linux Sound
Architecture (ALSA) framework.

%package alsabat
Summary: Advanced Linux Sound Architecture (ALSA) - Basic Audio Tester
BuildRequires: fftw-devel make

%description alsabat
This package contains tool for basic audio testing using Advanced Linux Sound
Architecture (ALSA) framework and Fast Fourier Transform library.

%prep
%autosetup -n %{name}-%{version}

%build
%configure CFLAGS="$RPM_OPT_FLAGS -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64" --disable-alsaconf \
   --with-udev-rules-dir=%{_prefix}/lib/udev/rules.d \
   --with-systemdsystemunitdir=%{_unitdir}
%make_build
cp %{SOURCE4} .

%install
%make_install
%find_lang %{name}

mkdir -p %{buildroot}/%{_prefix}/lib/udev/rules.d
install -p -m 644 %{SOURCE3} %{buildroot}/%{_prefix}/lib/udev/rules.d/90-alsa-restore.rules
mkdir -p %{buildroot}/%{_unitdir}
install -p -m 644 %{SOURCE5} %{buildroot}/%{_unitdir}/alsa-restore.service
install -p -m 644 %{SOURCE6} %{buildroot}/%{_unitdir}/alsa-state.service

mkdir -p -m755 %{buildroot}/%{_bindir}
install -p -m 755 %{SOURCE1} %{buildroot}/%{_bindir}
mkdir -p -m755 %{buildroot}/%{_mandir}/man1
install -p -m 644 %{SOURCE2} %{buildroot}/%{_mandir}/man1/alsaunmute.1

mkdir -p -m 755 %{buildroot}%{alsacfgdir}
mv %{buildroot}%{_datadir}/alsa/init %{buildroot}%{alsacfgdir}

ln -s ../../lib/alsa/init %{buildroot}%{_datadir}/alsa/init
mkdir -p -m 755 %{buildroot}/etc/alsa
install -p -m 644 %{SOURCE4} %{buildroot}/etc/alsa
mkdir -p -m 755 %{buildroot}%{_sharedstatedir}/alsa
find %{buildroot} -name "*.la" -exec rm {} \;

%pre
if [ ! -r %{_unitdir}/alsa-state.service ]; then
  [ -d /etc/alsa ] || mkdir -m 0755 /etc/alsa
  echo "# Remove this file to disable the alsactl daemon mode" > /etc/alsa/state-daemon.conf
fi

%post
if [ -s /etc/alsa/asound.state -a ! -s /etc/asound.state ] ; then
  mv /etc/alsa/asound.state /etc/asound.state
fi
if [ -s /etc/asound.state -a ! -s %{_sharedstatedir}/alsa/asound.state ] ; then
  mv /etc/asound.state %{_sharedstatedir}/alsa/asound.state
fi
%systemd_post alsa-state.service

%preun
%systemd_preun alsa-state.service

%postun
%systemd_postun_with_restart alsa-state.service

%files -f %{name}.lang
%license COPYING
%doc ChangeLog README.md TODO alsamixer/alsamixer.rc.example
%config /etc/alsa/*
%{_prefix}/lib/udev/rules.d/*
%{_unitdir}/*
%{_unitdir}/sound.target.wants/*
%{alsacfgdir}/init/*
%{_bindir}/aconnect
%{_bindir}/alsaloop
%{_bindir}/alsamixer
%{_bindir}/alsaunmute
%{_bindir}/amidi
%{_bindir}/amixer
%{_bindir}/aplay
%{_bindir}/aplaymidi
%{_bindir}/arecord
%{_bindir}/arecordmidi
%{_bindir}/aseqdump
%{_bindir}/aseqnet
%{_bindir}/axfer
%{_bindir}/iecset
%{_bindir}/speaker-test
%{_sbindir}/*
%exclude %{_sbindir}/alsabat-test.sh
%{_datadir}/alsa/
%{_datadir}/sounds/*
%{_mandir}/man7/*
%{_mandir}/man1/alsactl.1.gz
%{_mandir}/man1/alsaloop.1.gz
%{_mandir}/man1/alsamixer.1.gz
%{_mandir}/man1/alsaunmute.1.gz
%{_mandir}/man1/amidi.1.gz
%{_mandir}/man1/amixer.1.gz
%{_mandir}/man1/aplay.1.gz
%{_mandir}/man1/aplaymidi.1.gz
%{_mandir}/man1/arecord.1.gz
%{_mandir}/man1/arecordmidi.1.gz
%{_mandir}/man1/aseqdump.1.gz
%{_mandir}/man1/aseqnet.1.gz
%{_mandir}/man1/axfer.1.gz
%{_mandir}/man1/axfer-list.1.gz
%{_mandir}/man1/axfer-transfer.1.gz
%{_mandir}/man1/iecset.1.gz
%{_mandir}/man1/speaker-test.1.gz
%{_mandir}/man1/aconnect.1.gz
%{_mandir}/man1/alsa-info.sh.1.gz

%dir /etc/alsa/
%dir %{alsacfgdir}/
%dir %{alsacfgdir}/init/
%dir %{_sharedstatedir}/alsa/

%files -n alsa-ucm-utils
%{_bindir}/alsaucm
%{_mandir}/man1/alsaucm.1.gz

%files -n alsa-topology-utils
%{_bindir}/alsatplg
%{_mandir}/man1/alsatplg.1.gz
%{_libdir}/alsa-topology/libalsatplg_module_*

%files alsabat
%{_bindir}/alsabat
%{_sbindir}/alsabat-test.sh
%{_mandir}/man1/alsabat.1.gz

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.2.9-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Tue Sep 24 2024 cunshunxia <cunshunxia@tencent.com> - 1.2.9-4
- add systemd-devel buildrequire which contains pkgconf file.

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.2.9-3
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.2.9-2
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Jul 03 2023 kianli <kianli@tencent.com> - 1.2.9-1
- Upgrade to 1.2.9

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.2.8-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.2.8-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Dec 2 2022 Feng Weiyao <wynnfeng@tencent.com> - 1.2.8-1
- package init.
